#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.16
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import getCurrentBranch from '@gitmars/core/lib/git/getCurrentBranch';
import { spawnSync } from '@gitmars/core/lib/spawn';
import getConfig from '@gitmars/core/lib/getConfig';
import i18n from '#lib/locales/index';

const { red } = chalk;
const config = getConfig();
program.name("gitm permission").usage("[message] [--no-verify] [--dev] [--release]").arguments("[message]").description(i18n.__("Verify commit permissions")).option(
  "--no-verify",
  i18n.__("Do you want to skip the check permission"),
  false
).option("--dev", i18n.__("Whether to restrict dev commits"), false).option("--release", i18n.__("Whether to restrict release commits"), false).action((message, opt) => {
  console.info("gitm permission is running");
  const current = getCurrentBranch();
  const allow = [config.master];
  const { stdout } = spawnSync("git", ["show"]);
  if (opt.dev)
    allow.push(config.develop);
  if (opt.release)
    allow.push(config.release);
  const index = allow.indexOf(current);
  if (index > -1 && !opt.noVerify && stdout && !stdout.includes("Merge:") && !stdout.includes("Merge branch")) {
    sh.echo(
      red(
        i18n.__(
          "The {{{target}}} branch does not allow direct commits",
          {
            target: allow[index]
          }
        )
      )
    );
    process.exit(1);
  } else {
    process.exit(0);
  }
});
program.parse(process.argv);
