#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.16
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import { queue } from '@gitmars/core/lib/queue';
import getIsGitProject from '@gitmars/core/lib/git/getIsGitProject';
import getCurrentBranch from '@gitmars/core/lib/git/getCurrentBranch';
import { createArgs } from '@gitmars/core/lib/utils/command';
import saveConfig from '#lib/conf/save';
import i18n from '#lib/locales/index';

const { red } = chalk;
const { args, options } = saveConfig;
if (!getIsGitProject()) {
  sh.echo(
    red(i18n.__("The current directory is not a git project directory"))
  );
  process.exit(1);
}
program.name("gitm save").usage("[message] [-f --force]").description(i18n.__("Staging current branch files"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action((message, opt) => {
  if (!message)
    message = getCurrentBranch();
  message = `${message}_cache_by_gitmars`;
  let cmd = [
    {
      cmd: `git stash save "${message}"`,
      config: {
        success: i18n.__("File staging successful"),
        fail: i18n.__(
          "There was an error, please contact an administrator"
        )
      }
    }
  ];
  if (opt.force) {
    cmd = [
      "git add .",
      {
        cmd: `git stash save "${message}"`,
        config: {
          success: i18n.__("File staging successful"),
          fail: i18n.__(
            "There was an error, please contact an administrator"
          )
        }
      }
    ];
  }
  queue(cmd);
});
program.parse(process.argv);
